#
# spec file for package libhibr
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libhibr
%define lname	libhibr1
Version:        20210421
Release:        bp156.2.7
Summary:        Library and tools to access the Windows Hibernation File format
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libhibr
Source:         %name-%version.tar.xz
Patch1:         system-libs.patch
BuildRequires:  c_compiler
BuildRequires:  gettext-tools >= 0.18.1
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libbfio) >= 20201229
BuildRequires:  pkgconfig(libcdata) >= 20200509
BuildRequires:  pkgconfig(libcerror) >= 20201121
BuildRequires:  pkgconfig(libcfile) >= 20201229
BuildRequires:  pkgconfig(libclocale) >= 20200913
BuildRequires:  pkgconfig(libcnotify) >= 20200913
BuildRequires:  pkgconfig(libcpath) >= 20200623
BuildRequires:  pkgconfig(libcsplit) >= 20200703
BuildRequires:  pkgconfig(libcthreads) >= 20200508
BuildRequires:  pkgconfig(libfcache) >= 20200708
BuildRequires:  pkgconfig(libfdata) >= 20201129
BuildRequires:  pkgconfig(libfdatetime) >= 20180910
BuildRequires:  pkgconfig(libfwnt) >= 20210421
BuildRequires:  pkgconfig(libuna) >= 20201204

%description
libhibr is a library to access the Windows Hibernation File
(hiberfil.sys) format.

Part of the libyal family of libraries.

%package -n %lname
Summary:        Library for access the Windows Hibernation File format
Group:          System/Libraries

%description -n %lname
libhibr is a library to access the Windows Hibernation File
(hiberfil.sys) format.

Part of the libyal family of libraries.

%package devel
Summary:        Development files for libhibr
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libhibr is a library to access the Windows Hibernation File
(hiberfil.sys) format.

This subpackage contains libraries and header files for developing
applications that want to make use of libhibr.

%package tools
Summary:        Utilities to inspect Windows Hibernation Files
Group:          Productivity/File utilities

%description tools
This subpackage provides the utilities from libhibr, which allows for
inspecting Windows Hibernation Files (hiberfil.sys).

%prep
%autosetup -p1

%build
if [ ! -e configure ]; then ./autogen.sh; fi
# see libcdata for version-sc
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
%make_build

%install
%make_install
find "%buildroot" -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libhibr.so.*

%files devel
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/*.pc
%_mandir/man3/*.3*

%files tools
%_bindir/hibr*
%_mandir/man1/hibr*

%changelog
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon May 17 2021 Jan Engelhardt <jengelh@inai.de>
- Initial package for build.opensuse.org
  (version 20210421/commit b7caeb12)
- Add system-libs.patch
